.. epydemic documentation master file, created by
   sphinx-quickstart on Mon Jun 12 20:20:38 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

epydemic: Epidemic simulations on networks in Python
====================================================

.. automodule:: epydemic


Basic concepts and classes
--------------------------

.. toctree::
   :maxdepth: 2

   networkdynamics


Epidemic processes
------------------




Indices and tables
==================

* :ref:`genindex`
* :ref:`bibliography`
* :ref:`search`
